#include <M5Stack.h>
#include <M5GFX.h>
#include "UNIT_SCALES.h"

M5GFX display;
M5Canvas canvas(&display);
UNIT_SCALES scales;

void setup() {
    M5.begin();
    display.begin();
    canvas.setColorDepth(8);  // mono color
    canvas.setFont(&fonts::efontCN_12);
    canvas.createSprite(display.width(), display.height());
    canvas.setTextSize(2);
    while (!scales.begin(&Wire, 21, 22, DEVICE_DEFAULT_ADDR)) {
        Serial.println("scales connect error");
        M5.Lcd.print("scales connect error");
        delay(1000);
    }
    scales.setLEDColor(0x000010) ;

    scales.setLPFilter(1) ; // 0~1 : DEF 1
    scales.setAvgFilter(10);  // 0~50 : DEF 10
    scales.setEmaFilter(10);  // 0~99 : DEF 10
}

void loop() {
    float weight = scales.getWeight();
    int32_t weightInt = scales.getWeightInt();
    String weightStr = scales.getWeightString();
    float gap    = scales.getGapValue();
    int adc      = scales.getRawADC();
    uint8_t filterLP = scales.getLPFilter( );
    uint8_t filterAve = scales.getAvgFilter( );
    uint8_t filterEma = scales.getEmaFilter( );
    uint32_t ledColor = scales.getLEDColor();

    canvas.fillSprite(BLACK);
    canvas.setTextSize(2);
    canvas.setCursor(10, 10); canvas.setTextColor(WHITE); canvas.printf("WeightFlo:");
                              canvas.setTextColor(GREEN); canvas.printf("%.2fg", weight);
    canvas.setCursor(10, 30); canvas.setTextColor(WHITE); canvas.printf("WeightInt:");
                              canvas.setTextColor(GREEN); canvas.printf("%dg", weightInt);
    canvas.setCursor(10, 50); canvas.setTextColor(WHITE); canvas.printf("WeightStr:");
                              canvas.setTextColor(GREEN); canvas.printf("%sg", weightStr);
    canvas.setCursor(10, 70); canvas.setTextColor(WHITE); canvas.printf("ADC:");
                              canvas.setTextColor(GREEN); canvas.printf("%d", adc);
    canvas.setCursor(10, 90); canvas.setTextColor(WHITE); canvas.printf("GAP:");
                              canvas.setTextColor(GREEN); canvas.printf("%f", gap);
    canvas.setCursor(10, 120);canvas.setTextColor(WHITE); canvas.printf("Filter LP :");
                              canvas.setTextColor(GREEN); canvas.printf("%02X", filterLP);
    canvas.setCursor(10, 140);canvas.setTextColor(WHITE); canvas.printf("Filter Ave :");
                              canvas.setTextColor(GREEN); canvas.printf("%02X", filterAve);
    canvas.setCursor(10, 160);canvas.setTextColor(WHITE); canvas.printf("Filter Ema :");
                              canvas.setTextColor(GREEN); canvas.printf("%02X", filterEma);
    canvas.setCursor(10, 180);canvas.setTextColor(WHITE); canvas.printf("LED COLOR :");
                              canvas.setTextColor(GREEN); canvas.printf("%03X", ledColor);

    canvas.setTextColor(ORANGE); canvas.drawString("[Offset]", 110, 210);

    canvas.pushSprite(0, 0);
    M5.update();
    if (M5.BtnB.wasPressed()) {
        scales.setOffset();
    }
}
