#include <M5Stack.h>
#include <M5GFX.h>
#include "UNIT_SCALES.h"

M5GFX display;
M5Canvas canvas(&display);
UNIT_SCALES scales;
int Adc_0g = 0 ;
int Adc_100g = 0 ;
float CalibrationGap = 175.221130 ;
int stepMode = 0;
int CalibrationMode = 0; // 0:Auto 1:Manmual

int baseAdc = 0 ;

void setup() {
    M5.begin();
    display.begin();
    canvas.setColorDepth(8);  // mono color
    canvas.setFont(&fonts::efontCN_12);
    canvas.createSprite(display.width(), display.height());
    canvas.setTextSize(2);
    while (!scales.begin(&Wire, 21, 22, DEVICE_DEFAULT_ADDR)) {
        Serial.println("scales connect error");
        M5.Lcd.print("scales connect error");
        delay(1000);
    }
    scales.setLEDColor(0x001000);
    CalibrationGap = scales.getGapValue();
    baseAdc    = scales.getRawADC();
}

void loop() {
    float weight = scales.getWeight();
    float gap    = scales.getGapValue();
    int   adc    = scales.getRawADC();

    Serial.print(baseAdc);
    Serial.print(",");
    Serial.println(adc);

    canvas.fillSprite(BLACK);

    canvas.setTextSize(2);
    canvas.drawString("Unit Scale Calibration", 10, 0);
    canvas.setTextColor(BLUE);
    canvas.setTextColor(DARKGREY);
    canvas.setCursor(10, 20);
    canvas.printf("  0G:");
    canvas.setTextColor(BLUE);
    canvas.printf("%d", Adc_0g);

    canvas.setTextColor(DARKGREY);
    canvas.setCursor(10, 40);
    canvas.printf("100G:");
    canvas.setTextColor(BLUE);
    canvas.printf("%d", Adc_100g);

    canvas.setTextColor(DARKGREY);
    canvas.setCursor(10, 60);
    canvas.printf("GAP:");
    canvas.setTextColor(BLUE);
    canvas.printf("%f", CalibrationGap);

    // -----
    canvas.setTextSize(3);
    canvas.setTextColor(WHITE);
    canvas.setCursor(10, 95);
    canvas.printf("WEIGHT:");
    canvas.setTextColor(GREEN);
    canvas.printf("%.2fg", weight);

    canvas.setCursor(10, 135);
    canvas.setTextColor(WHITE);
    canvas.printf("ADC:");
    canvas.setTextColor(GREEN);
    canvas.setTextSize(3);
    canvas.printf("%d", adc);

    canvas.setCursor(10, 170);
    canvas.setTextColor(WHITE);
    canvas.printf("GAP:");
    canvas.setTextColor(GREEN);
    canvas.setTextSize(3);
    canvas.printf("%f", gap);

    // --- BUTTON --
    canvas.setTextColor(ORANGE);
    canvas.setTextSize(2);

    canvas.drawString("[Mode ]",   0, 210);
    if (CalibrationMode == 0) {
      canvas.drawString("[Reset]", 110, 210);
      String btnCStr = "[0g   ]" ;
      if (stepMode == 2) {
        btnCStr = "[100g ]" ;
      } else 
      if (stepMode == 3) {
        btnCStr = "[SetGAP]" ;
      }
      canvas.drawString(btnCStr, 220, 210);
    } else {
      canvas.drawString("[GAP+ ]", 110, 210);
      canvas.drawString("[GAP- ]", 220, 210);    
    }

    canvas.pushSprite(0, 0);

    M5.update();
    if (M5.BtnA.wasPressed()) {
        CalibrationMode = (CalibrationMode == 0) ? 1 : 0 ;
        scales.setLEDColor((CalibrationMode == 0) ? 0x001000 : 0x100000 );
        stepMode = 1;
    }
    if (CalibrationMode == 0) {
      if (M5.BtnB.wasPressed()) {
          scales.setOffset();
          baseAdc = adc ;
          scales.setLEDColor(0x000010);
          stepMode = 1 ;
      }
      if (M5.BtnC.wasPressed()) {
        if (stepMode == 1) {
          Adc_0g = adc;
          stepMode = 2 ;
        } else
        if (stepMode == 2) {
          Adc_100g = adc;
          CalibrationGap = ((long)Adc_0g - Adc_100g) / 100.0 ;
          stepMode = 3 ;
        } else
        if (stepMode == 3) {
          scales.setGapValue(CalibrationGap) ;
          scales.setLEDColor(0x001000);
          stepMode = 0 ;
        }
      }
    } else {
      if (M5.BtnB.wasPressed()) {
        gap += 0.1;
        scales.setGapValue(gap) ;
      }
      if (M5.BtnC.wasPressed()) {
        gap -= 0.1;
        scales.setGapValue(gap) ;
      }      
    }
}
